import { Control } from "../control/page";
import { FileOperation, SASObjectAttachedFile } from "../file/file-api";
import { ObjectFieldRestrictions } from "../object/object-api";
export declare enum PageMode {
    Create = "create",
    Edit = "edit",
    View = "view",
    Design = "design"
}
export declare const enum ServerPageMode {
    CREATE = "C",
    EDIT = "E",
    VIEW = "V"
}
export interface Condition {
    type: string;
    parameters: Array<string | number | boolean | Condition>;
}
export interface PageAction {
    attrs: {
        actionId: number;
        actionName: string;
        attributes: {
            [property: string]: any;
            displayName: string;
            disabled: string;
        };
        controlId?: number;
        displayName: string;
    };
}
export interface PageActions {
    items?: PageAction[];
}
export interface PageModelData {
    [property: string]: any;
}
export interface PageModelObjectData {
    clientApplication: string;
    data: PageModelData;
    displayLabel?: string;
    fieldRestrictions?: ObjectFieldRestrictions;
    fileRestrictions?: ObjectFieldRestrictions;
    id?: string;
    linkedPages?: any[];
    mode?: PageMode;
    objectTypeId?: string;
    objectTypeVersion?: number;
    serverPageMode?: ServerPageMode;
    template?: PageTemplate;
    templateMetadata?: PageTemplateMetadata;
    toolbar?: {
        disabled: boolean;
        items: Control[];
    };
    type?: string;
}
export interface PageModel extends PageModelObjectData {
    attachmentCount?: number;
    disableDragDrop?: boolean;
    fileOperations?: FileOperation[];
    isFormSearch?: boolean;
    isSourceDocument?: boolean;
    parent?: PageModel;
    updateData(data: PageModelData | undefined): void;
    isEditable(): boolean;
    isInCreateMode(): boolean;
    isValid(): Promise<boolean>;
    addFileOperation(operation: string, id: string, data?: SASObjectAttachedFile): void;
    removeFileOperation(operation: string, id: string): void;
    removeAllFileOperations(): void;
    getAllMissingFileCategories(): Promise<string[]>;
    getAllMissingRequiredFields(): string[];
    setParentModel(parentModel: PageModel): void;
    getParentModel(): PageModel;
    destroy(): void;
}
export interface PageTemplate {
    errors?: boolean;
    errorDetails?: Error;
    showTabs: boolean;
    id?: number;
    screens: PageTemplateScreen[];
}
export interface PageTemplateMetadata {
    dataSources: PageTemplateMetadataDataSource[];
    insightsCreationEnabled: boolean;
    insightsEnabled: boolean;
    linkedTemplates: any[];
    resources: {
        [property: string]: string;
    };
    workspaceCreationEnabled: boolean;
    workspaceEnabled: boolean;
}
export interface PageTemplateMetadataDataSource {
    objectName: string;
    fields: string[];
}
export interface PageTemplateScreen {
    id: string;
    name: string;
    locked?: boolean;
    childNodes?: Control[];
}
/**
 * This API is used for creating a PageModel object from source data.
 * Accessed from the window at window.sas.vi.pageModel.
 */
export interface PageModelApi {
    /**
     * @method
     * @description Creates a new instance of a PageModel when given the object source.
     * @param objectSource {PageModelObjectData} Object containing data for the page model.
     * @param [options] {PageModelApi~CreateFromObjectOptions} Contains a boolean "clone" declaring whether to deep clone the object
     * when creating the Page Model.
     * @returns The instance of PageModel
     */
    createFromObject(objectSource: PageModelObjectData, options?: {
        clone?: boolean;
    }): PageModel;
}
/**
 * @typedef {object} PageModelApi~CreateFromObjectOptions
 * @property [clone] {boolean} Whether or not to clone the page model data or use the referenced values.
 */
