/**
 * SAS Visual Investigator API's representation of a UI-Router state.
 * Accessed from the window at window.sas.vi.pageState.
 */
export interface StateObject {
    /** The parent StateObject. */
    parent: StateObject;
    /** Name used to register the state. */
    name: string;
    /** Parent StateObject array from this state up to the root. */
    path: StateObject[];
    data: any;
    /**
     * An object containing the parent States' names as keys and
     * true as their values.
     */
    includes: {
        [name: string]: boolean;
    };
    /**
     * Function to return the root node of this state's tree.
     *
     * @returns The root of this state's tree.
     */
    root(): StateObject;
    toString(): string;
}
/**
 * This API provides functionality that pertains to the page state.
 * Accessed from the window at window.sas.vi.pageState.
 */
export interface PageStateApi {
    /**
     * @method
     * @description Returns the state of the current page.
     * @returns An object containing the page state data or undefined if no page exists.
     */
    getCurrent(): StateObject | undefined;
    /**
     * @method
     * @description Returns the state of the page matching the ID.
     * @param id {string | number} Page ID for which the state will be returned.
     * @returns An object containing the page state data or undefined if the ID doesn't exist.
     */
    get(id: string | number): StateObject | undefined;
    /**
     * @method
     * @description Creates a page state.
     * @param id {string | number} Page ID to be created.
     * @param state {StateObject} Object containing the state data required to create the page.
     */
    add(id: string | number, state: StateObject): void;
    /**
     * @method
     * @description Deletes a page state.
     * @param id {string | number} ID of the page to be deleted.
     */
    remove(id: string | number): void;
}
