import { Control } from "../control/page";
import { TypeAttributes } from "../object/object-api";
import { PageTemplateMetadata } from "../page-model/page-model-api";
export interface ToolbarPropertyControl {
    typeAttributes: TypeAttributes;
}
export interface PropertyConfig {
    [property: string]: any;
    order?: number;
    required?: boolean;
    type: string;
}
/**
 * This API provides the  utility or miscellaneous functionality in SAS Visual Investigator.
 * Accessed from the window at window.sas.vi.property.
 */
export interface PropertyApi {
    /**
     * @method
     * @description Registers a custom element to be rendered as the property editor.
     * The element is rendered as a custom web component.
     * The element is passed selectedNode, property, propertyKey and categoryKey as attributes.
     * Throws a console error if the type is already used by another registered editor.
     * @param elementName {string} Element to be rendered. For example "custom-editor" renders an element with the tag name "custom-editor".
     * @param type {string} A custom type that is expected to be unique among registered editors.
     * @param [validatorFn] {PropertyApi~isPropertyEditorValid} Function to provide custom logic for determining if the editor is valid.
     * @param [metadataFn] {PropertyApi~getPropertyEditorMetadata} Function to provide custom metadata.
     */
    registerCustomEditor(elementName: string, type: string, validatorFn?: (propertyConfig: PropertyConfig, propertyKey: string, control: Control | ToolbarPropertyControl) => boolean, metadataFn?: (propertyConfig: PropertyConfig, propertyKey: string, control: Control | ToolbarPropertyControl) => PageTemplateMetadata): void;
}
/**
 * Determines whether or not the property editor is valid.
 * @callback PropertyApi~isPropertyEditorValid
 * @param {PropertyConfig} propertyConfig Configuration details relating to the custom property type. For example, required, type and so on.
 * @param {string} propertyKey Key where this property's value is stored.
 * @param {Control | ToolbarPropertyControl} control The control.
 * @returns {boolean} true if valid, false if not.
 */
/**
 * Get metadata for the property editor.
 * @callback PropertyApi~getPropertyEditorMetadata
 * @param {PropertyConfig} propertyConfig Configuration details relating to the custom property type. For example, required, type and so on.
 * @param {string} propertyKey Key where this property's value is stored.
 * @param {Control | ToolbarPropertyControl} control The control.
 * @returns {PageTemplateMetadata}
 */
